start

## Support for TMX

Although TMX is supposed to be an exchange standard, not all tools create or read standard TMX files, and consequently some tools may not be able to use the Toolkit's TMXes and vice versa.

Have a good Unicode editor handy so that you can fiddle with the encoding of the file in extreme cases. For MS Windows users, we suggest Babelpad.

#### How they were tested

I tested other tools by checking if they import Toolkit TMXes without complaint, and in some cases if I could get translation matches from it. I tested their TMXes with the Toolkit by doing a pocount on the TMX and doing a pot2po (with --tm=file.tmx) on a file with known matches.

### Support for Toolkit TMXes

#### Virtaal

Since these tests were made, we have also released Virtaal, which can use TMX files as well as many other formats.

#### Cafetran 2007

Seems fully compatible with Tranlate-toolkit, in both directions. Cafetran imports our TMX without complaints. A Cafetran user was able to read and use one of our TMXes, and we were able to test and use one of the Cafetran user's TMXes.

#### Wordfast 5

Fully compatible with Translate-toolkit. Wordfast opens our TMXes directly and converts them to its own internal format. Wordfast can also export to TMX, which can be read by our tools. Remember, Wordfast's Unicode format is UTF16LE with BOM, so if you run into problems, try converting it by character encoding. Wordfast 3 and 4 should also work.

#### Trados 2007 (Workbench 8)

Possibly compatible with Translate-toolkit. To import using Trados, first create a Trados TM and then import the TMX into it. Trados did import our test TMX (22000 segments) but it lost about 30% of the segments in the process. Our tools can read TMXes exported from Trados.

#### OmegaT 1.6

Fully compatible with Translate-toolkit. Simply place our TMXes in the /tm/ folder of your project. All of OmegaT's exported TMXes can be read by the Translate-toolkit -- although which one you use will depend on what your workflow is (i.e. with OmegaT's internal tags or without them).

### No or little support for Toolkit TMXes

#### Aid Trans Professional 2.0

Actually, this tool is still in beta and it kept crashing when I tested it, but I was able to discover one thing: the TMX DTD (called tmx14.dtd) must be in the same folder as the TMX file you're trying to import.

#### Transolution

I was unable to test this tool because I couldn't figure out how it works.

#### Across

This tool was too big for me to test (several hundreds of megabytes).

#### Deja Vu

I was unable to test this tool because I couldn't figure out how it works.